| MCreport | R Documentation |
Efficient Monte Carlo sampling of parameters (and REPORTed quantities) from the approximate posterior of an (R)TMB model.
See sdreport for details on posterior variance-covariance in random effects models.
MCreport(
obj,
nSamples = 1000,
include_random_pars = TRUE,
report = FALSE,
Q = NULL,
...
)
obj |
Optimised |
nSamples |
Number of samples to draw |
include_random_pars |
Logical; Should random parameters be included in the output? |
report |
Logical; Should |
Q |
Optional precalculated sparse precision matrix returned by |
... |
For internal use only |
Caution: This has nothing to do with Bayesian posterior sampling. It is simple Monte Carlo sampling from a Gaussian distribution with mean at the MLE and covariance given by the inverse of the Hessian (for fixed effects models) or the joint precision matrix (for random effects models). This is a common approach to get an approximate idea of parameter uncertainty around the MLE, but it relies on large-sample asymptotics.
Sampling random effects from their posterior as compared to calculating marginal standard devitions like sdreport is particularly useful for multidimensional random effects (e.g. for locations x and y)
where pointwise confidence intervals (e.g. along a path) based on standard deviations are not possible.
A list structured like the original parameter list used in the MakeADFun call (potentially including additional REPORTed quantities). Each entry is a list with nSamples entries.
step <- trex$step[1:2000] # subsetting trex data
N <- 2 # 2 states
# custom likelihood
nll <- function(par) {
getAll(par)
Gamma <- tpm(eta)
delta <- stationary(Gamma)
mu <- exp(log_mu); REPORT(mu)
sigma <- exp(log_sigma); REPORT(sigma)
allprobs <- matrix(1, length(step), N)
for(j in 1:N) allprobs[,j] <- dgamma2(step, mu[j], sigma[j])
-forward(delta, Gamma, allprobs)
}
# initial parameters in named list
par0 <- list(eta = rep(-1.5,2),
log_mu = log(c(0.3, 2.5)),
log_sigma = log(c(0.3, 1.5)))
# constructing AD object
obj <- MakeADFun(nll, par0, silent = TRUE)
# optimising
opt <- nlminb(obj$par, obj$fn, obj$gr)
# sampling from distribution of the MLE
samples <- MCreport(obj, nSamples = 10, report = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.