View source: R/forward_algorithms.R
| forward_g | R Documentation |
Calculates the log-likelihood of a sequence of observations under a hidden Markov model with time-varying transition probabilities using the forward algorithm (Zucchini, MacDonald & Langrock, 2016).
forward_g(
delta,
Gamma,
allprobs,
trackID = NULL,
logspace = FALSE,
bw = NULL,
report = TRUE,
ad = NULL
)
delta |
initial distribution; either
|
Gamma |
array of transition probability matrices of dimension For a single track, an array of dimension This function also supports continuous-time HMMs, where each slice is a Markov semigroup
|
allprobs |
matrix of state-dependent probabilities or density values of dimension |
trackID |
optional vector of length |
logspace |
logical; if |
bw |
optional positive integer specifying the bandwidth for a banded approximation of the forward algorithm, inducing a banded Hessian w.r.t. the observations.
Defaults to |
report |
logical; if |
ad |
logical; whether to use automatic differentiation. Determined automatically — for debugging only. |
If trackID is provided, the total log-likelihood will be the sum of each track's likelihood contribution.
In this case, Gamma must be an array of dimension c(nStates, nStates, nObs), matching the number of rows of allprobs. For each track, the transition matrix at the beginning of the track will be ignored (as there is no transition between tracks).
Additionally, delta can be a vector (same initial distribution for each track) or a matrix of dimension c(nTracks, nStates) (different initial distribution for each track).
Note: When there are multiple tracks, for compatibility with downstream functions like viterbi_g, stateprobs_g or pseudo_res,
forward_g should only be called once with a trackID argument.
HMM log-likelihood for given data and parameters
Zucchini, W., MacDonald, I.L., & Langrock, R. (2016). Hidden Markov Models for Time Series: An Introduction Using R (2nd ed.). Chapman & Hall/CRC.
Mews, Koslik, & Langrock (2025). How to build your latent Markov model: The role of time and space. Statistical Modelling, 25(6), 481–507.
Other forward algorithms:
forward(),
forward_hsmm(),
forward_ihsmm(),
forward_p(),
forward_phsmm()
## Simple usage
Gamma = array(c(0.9, 0.2, 0.1, 0.8), dim = c(2,2,10))
delta = c(0.5, 0.5)
allprobs = matrix(0.5, 10, 2)
forward_g(delta, Gamma, allprobs)
## Full model fitting example
## negative log likelihood function
nll = function(par, step, Z) {
# parameter transformations for unconstrained optimisation
beta = matrix(par[1:6], nrow = 2)
Gamma = tpm_g(Z, beta) # multinomial logit link for each time point
delta = stationary(Gamma[,,1]) # stationary HMM
mu = exp(par[7:8])
sigma = exp(par[9:10])
# calculate all state-dependent probabilities
allprobs = matrix(1, length(step), 2)
ind = which(!is.na(step))
for(j in 1:2) allprobs[ind,j] = dgamma2(step[ind], mu[j], sigma[j])
# simple forward algorithm to calculate log-likelihood
-forward_g(delta, Gamma, allprobs)
}
## fitting an HMM to the trex data
par = c(-1.5,-1.5, # initial tpm intercepts (logit-scale)
rep(0, 4), # initial tpm slopes
log(c(0.3, 2.5)), # initial means for step length (log-transformed)
log(c(0.2, 1.5))) # initial sds for step length (log-transformed)
mod = nlm(nll, par, step = trex$step[1:500], Z = cosinor(trex$tod[1:500]))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.