- Z
Covariate design matrix with or without intercept column, i.e. of dimension c(nObs, p) or c(nObs, p+1).
If not provided, intercept column is added automatically.
- beta
Matrix of coefficients for the off-diagonal elements of the transition probability matrix
of dimension c(nStates * (nStates-1), p+1). First columns contains the intercepts.
- Eta
optional pre-calculated matrix of linear predictors of dimension c(nObs, nStates * (nStates-1)).
If provided, no Z and beta are necessary and will be ignored.
- byrow
logical indicating if each transition probability matrix should be filled by row.
Defaults to FALSE, but should be set to TRUE if one wants to work with a matrix of beta parameters returned by popular HMM packages like moveHMM, momentuHMM, or hmmTMB.
- ref
optional integer vector of length nStates giving, for each row, the column index of the reference state
(its predictor is fixed to 0). Defaults to the diagonal (ref = 1:nStates).
- ad
logical; whether to use automatic differentiation. Determined automatically — for debugging only.
- report
logical; if TRUE (default), delta, Gamma, allprobs, and trackID are reported from the fitted model. Requires ad = TRUE.
- sparse
logical, indicating whether sparsity in the rows of Z should be exploited.