viterbi_g: Viterbi algorithm for state decoding in inhomogeneous HMMs
Description
The Viterbi algorithm decodes the most probable state sequence of an HMM.
Usage
viterbi_g(delta, Gamma, allprobs, trackID = NULL, mod = NULL)
Value
vector of decoded states of length nObs
Arguments
delta
initial distribution; either
a vector of length nStates, or
a matrix of dimension c(nTracks, nStates) if trackID is provided
Gamma
array of transition probability matrices of dimension c(nStates, nStates, nObs),
where the first slice of each track is ignored as there is no transition into the start of a track.
For a single track, an array of dimension c(nStates, nStates, nObs-1) is also accepted.
allprobs
matrix of state-dependent probabilities or density values of dimension c(nObs, nStates)
trackID
optional vector of length nObs containing nTracks unique IDs that separate tracks
mod
optional model object containing delta, Gamma, allprobs, and
optionally trackID. When using RTMB::MakeADFun or qreml with
forward_g in the likelihood, these are reported automatically after model fitting
and the object returned by RTMB::report() or qreml can be passed directly.
See Also
Other decoding functions:
stateprobs(),
stateprobs_g(),
stateprobs_p(),
viterbi(),
viterbi_p()